multivitamin.applications.images package
========================================

Subpackages
-----------

.. toctree::

   multivitamin.applications.images.classifiers
   multivitamin.applications.images.detectors

Submodules
----------

multivitamin.applications.images.frame\_drawer module
-----------------------------------------------------

.. automodule:: multivitamin.applications.images.frame_drawer
   :members:
   :undoc-members:
   :show-inheritance:

multivitamin.applications.images.frame\_extractor module
--------------------------------------------------------

.. automodule:: multivitamin.applications.images.frame_extractor
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: multivitamin.applications.images
   :members:
   :undoc-members:
   :show-inheritance:
